@@ -5,6 +5,7 @@
 */
 
 #include "importwizard-version.h"
+
 #include "importwizard.h"
 #include <KAboutData>
 #include <KCrash>
@@ -19,6 +20,7 @@
 
 #include <KStyleManager>
 
+using namespace Qt::Literals::StringLiterals;
 int main(int argc, char *argv[])
 {
     KIconTheme::initTheme();
@@ -26,24 +28,24 @@ int main(int argc, char *argv[])
     KStyleManager::initStyle();
 
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("akonadiimportwizard"));
-    // FIXME: "wizards" are "assistents" in new KDE slang
+    // FIXME: "wizards" are "assistants" in new KDE slang
 
-    KAboutData aboutData(QStringLiteral("importwizard"),
+    KAboutData aboutData(u"importwizard"_s,
                          i18n("PIM Import Tool"),
                          QStringLiteral(KDEPIM_VERSION),
                          i18n("PIM Import Tool"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2012-%1 ImportWizard authors", QStringLiteral("2025")));
+                         i18n("Copyright © 2012-%1 ImportWizard authors", u"2025"_s));
 
-    aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
-    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kontact-import-wizard")));
+    aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), u"montel@kde.org"_s);
+    QApplication::setWindowIcon(QIcon::fromTheme(u"kontact-import-wizard"_s));
     aboutData.setProductName(QByteArrayLiteral("kmail2/import wizard"));
-    aboutData.setDesktopFileName(QStringLiteral("org.kde.akonadiimportwizard"));
+    aboutData.setDesktopFileName(u"org.kde.akonadiimportwizard"_s);
     KAboutData::setApplicationData(aboutData);
     KCrash::initialize();
 
     QCommandLineParser parser;
-    const QCommandLineOption modeOption(QStringList() << QStringLiteral("mode"), i18nc("@info:shell", "Mode: %1", QStringLiteral("manual|automatic")));
+    const QCommandLineOption modeOption(QStringList() << u"mode"_s, i18nc("@info:shell", "Mode: %1", u"manual|automatic"_s));
     parser.addOption(modeOption);
     aboutData.setupCommandLine(&parser);
     parser.process(app);
